@@ -146,17 +146,6 @@ extern intgen_t diriter( jdm_fshandle_t *fshandlep,
 			 size_t usrgdsz );
 
 
-
-/* ctimennl - ctime(3C) with newline removed
- */
-extern char *ctimennl( const time32_t *clockp );
-
-/* ctime32 - takes a time32_t instead of a time_t
- */
-extern char *ctime32( const time32_t *timep );
-
-
-
 /* fold_t - a character string made to look like a "fold here"
  */
 #define FOLD_LEN	79
